#!/bin/sh
# Copyright © 2023. Duet, Inc. All rights reserved.

set -e
set -o pipefail

# Function to get the directory of the current script
get_script_dir() {
    # Use "$1" to get the directory of the current script
    local script_path="$1"
    # Change to the directory of the script
    local script_dir="$(cd "$(dirname "$script_path")" && pwd)"
    echo "$script_dir"
}

# Function to execute a command and log its success or failure
execute_and_log() {
    local cmd="$1"
    echo "Executing: $cmd"
    eval "$cmd"
    local exit_code=$?
    if [ $exit_code -eq 0 ]; then
        echo "Success: $cmd"
    else
        echo "Failed: $cmd with exit code $exit_code"
    fi
    return $exit_code
}

SCRIPT_DIR=$(get_script_dir "$0")
echo "Script directory: $SCRIPT_DIR"

# Copy the daemon's launchd.plist into /Library/LaunchAgents
for plist in com.kairos.DuetHelper.plist
do
    trg=/Library/LaunchAgents/com.kairos.DuetHelper.plist

    execute_and_log "cp '${SCRIPT_DIR}/${plist}' '${trg}'"
    execute_and_log "chown root:wheel '${trg}'"
    execute_and_log "chmod 644 '${trg}'"
done
