#!/bin/sh
# Copyright © 2023. Duet, Inc. All rights reserved.

set -e
set -o pipefail

# Function to get the directory of the current script
get_script_dir() {
    # Use "$1" to get the directory of the current script
    local script_path="$1"
    # Change to the directory of the script
    local script_dir="$(cd "$(dirname "$script_path")" && pwd)"
    echo "$script_dir"
}

# Function to execute a command and log its success or failure
execute_and_log() {
    local cmd="$1"
    echo "Executing: $cmd"
    eval "$cmd"
    local exit_code=$?
    if [ $exit_code -eq 0 ]; then
        echo "Success: $cmd"
    else
        echo "Failed: $cmd with exit code $exit_code"
    fi
    return $exit_code
}

# Logging the input parameter
echo "Input parameter: $1"

# Determine working directory
if [ -z "$1" ]; then
    WORK_DIR=$(get_script_dir "$0")
    echo "No input parameter provided, using script directory as WORK_DIR: $WORK_DIR"
else
    WORK_DIR="$1"
    echo "Using provided input parameter as WORK_DIR: $WORK_DIR"
fi

# Copy the daemon's launchd.plist into /Library/LaunchDaemons
for plist in com.kairos.DuetDaemon.plist
do
    trg=/Library/LaunchDaemons/com.kairos.DuetDaemon.plist

    execute_and_log "cp '${WORK_DIR}/${plist}' '${trg}'"
    execute_and_log "chown root:wheel '${trg}'"
    execute_and_log "chmod 644 '${trg}'"
done

# Ensure the core service has access to this key in the keychain
if [ -z "$1" ]; then
    execute_and_log "security add-generic-password -U -s com.kairos.DuetDaemon -a duetServicesAccount -T /Applications/duet.app/Contents/SharedSupport/DuetDaemon /Library/Keychains/System.keychain"
else
    echo "Skipping keychain update due to provided input parameter"
fi
