#!/bin/sh
# Copyright © 2023. Duet, Inc. All rights reserved.

# set -e
set -o pipefail

# Function to execute a command and log its success or failure
execute_and_log() {
    local cmd="$1"
    echo "Executing: $cmd"
    eval "$cmd"
    local exit_code=$?
    if [ $exit_code -eq 0 ]; then
        echo "Success: $cmd"
    else
        echo "Failed: $cmd with exit code $exit_code"
    fi
    return $exit_code
}

echo "Uninstalling coreservice"
if [ -f /Library/LaunchDaemons/com.kairos.DuetDaemon.plist ]; then
    echo "Found coreservice launchd plist"

    # if launchctl list | grep -q com.kairos.DuetDaemon; then
    echo "Boot-out coreservice component"
    execute_and_log "launchctl bootout system /Library/LaunchDaemons/com.kairos.DuetDaemon.plist"
    # fi

    echo "Deleting coreservice launchd plist"
    execute_and_log "rm /Library/LaunchDaemons/com.kairos.DuetDaemon.plist"
else
    echo "Coreservice launchd plist not found"
fi

echo "Removing duet account from system keychain"
execute_and_log "security delete-internet-password -s duetdisplay.com -a duetServicesAccount /Library/Keychains/System.keychain"

exit 0
